@@ -152,7 +152,7 @@ on_radiobuttonTypeMousePointer_toggled (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_combo_entry16_changed               (GtkEditable     *editable,
+on_entryActionName_changed               (GtkEditable     *editable,
                                         gpointer         user_data);
 
 void
@@ -474,7 +474,7 @@ on_spinSpacing_changed                 (GtkEditable     *editable,
                                         gpointer         user_data);
 
 void
-on_combo_entry16_changed               (GtkEditable     *editable,
+on_entryActionName_changed               (GtkEditable     *editable,
                                         gpointer         user_data);
 
 void
@@ -497,10 +497,6 @@ void
 on_radiobuttonTypeMouseButton_toggled  (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_radiobuttonTypeDwell_toggled        (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_radiobuttonTypeMousePointer_toggled (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -526,11 +522,11 @@ on_radiobuttonSwitch5_toggled          (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_radiobuttonSwitchPressed_toggled    (GtkToggleButton *togglebutton,
+on_radiobuttonSwitchPress_toggled      (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
-on_radiobutton1SwitchReleased_toggled  (GtkToggleButton *togglebutton,
+on_radiobutton1SwitchRelease_toggled   (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
@@ -609,26 +605,6 @@ void
 on_buttonChangeFeedbackName_clicked    (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_radiobuttonMouseButton0_toggled     (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_radiobuttonMouseButton1_toggled     (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_radiobuttonMouseButton2_toggled     (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_radiobuttonMouseButton3_toggled     (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-void
-on_radiobuttonMouseButton4_toggled     (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_radiobuttonButtonPressed_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -641,11 +617,6 @@ void
 on_radiobuttonButtonClicked_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_radiobuttonButtonDoubleClicked_toggled
-                                        (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_radiobuttonButtonPress_toggled      (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -658,11 +629,6 @@ void
 on_radiobuttonButtonClick_toggled      (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
-void
-on_radiobuttonButtonDoubleClick_toggled
-                                        (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_radiobuttonSwitchPress_toggled      (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -764,3 +730,122 @@ on_dialogSettings_delete_event         (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
+void
+on_spinDwellRate_changed               (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_checkKeyAverage_toggled             (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_spinKeyAverage_changed              (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_radiobuttonTypeValuator_toggled     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_action_type_notebook_change_current_page
+                                        (GtkNotebook     *notebook,
+                                        gint             offset,
+                                        gpointer         user_data);
+
+void
+on_2d_valuator_radiobutton_toggled     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_1d_radiobutton_toggled              (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_axis_selection_spinbutton_changed   (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_activate_on_enter_button_toggled    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_activate_on_dwell_button_toggled    (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_activate_on_move_button_toggled     (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_pointer_delay_spinbutton_changed    (GtkEditable     *editable,
+                                        gpointer         user_data);
+
+void
+on_key_averaging_button_toggled        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_core_pointer_button_toggled         (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_xinput_device_button_toggled        (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_joystick_button_toggled             (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+
+void
+on_buttonNewAction_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonDeleteAction_clicked          (GtkButton       *button,
+                                        gpointer         user_data);
+
+
+void
+on_checkExtraWordList_toggled          (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
+void
+on_buttonHelp_clicked                  (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonApply_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonRevert_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonCancel_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonOK_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonHelp_clicked                  (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonApply_clicked                   (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonRevert_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonCancel_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_buttonOK_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
