@@ -31,12 +31,19 @@
 #include "gok-word-complete.h"
 #include "main.h"
 #include "gok-gconf-keys.h"
+#include "gok-data.h"
+#include "gok-gconf.h"
+
+extern long keysym2ucs(KeySym keysym);
 
 static gboolean
 gok_output_can_predict (void)
 {
 	GokKeyboard *kbd = gok_main_get_current_keyboard ();
-	return (kbd && !gok_main_get_login() && gok_data_get_wordcomplete () &&
+	Accessible *acc_with_text = gok_spy_get_accessibleWithText ();
+	gboolean is_password = (acc_with_text && 
+	    Accessible_getRole (acc_with_text) == SPI_ROLE_PASSWORD_TEXT);
+	return (kbd && !gok_main_get_login() && !is_password && gok_data_get_wordcomplete () &&
 		gok_keyboard_get_supports_wordcomplete (kbd));
 }
 
@@ -259,7 +266,7 @@ GokOutput* gok_output_new_from_xml (xmlNode* pNode)
 		return NULL;
 	}
 
-	return gok_output_new (typeOutput, g_strstrip (xmlNodeGetContent (pNode)), flagOutput);
+	return gok_output_new (typeOutput, g_strstrip ((char *)xmlNodeGetContent (pNode)), flagOutput);
 }
 
 static gunichar
@@ -346,8 +353,7 @@ void gok_output_send_to_system (GokOutput* pOutput, gboolean bWordCompletion)
 			
 			gok_log ("Sending a keysym");
 			gok_log ("pOutput->Name = %s", pOutput->Name);
-			gok_log ("SPI_KEY_SYM = %d", (int) keysym);
-
+			gok_log ("SPI_KEY_SYM = %s [%d]", pOutput->Name, (int) keysym);
 			SPI_generateKeyboardEvent ((long) keysym, NULL, SPI_KEY_SYM);
 
 			/* update the word prediction keys with the new output */
@@ -484,13 +490,13 @@ gok_output_get_keycode (GokOutput *output)
     if (output && output->Type == OUTPUT_KEYCODE)
 	keycode = atoi (output->Name);
     else if (output && output->Type == OUTPUT_KEYSYM)
+    {
 	keycode = XKeysymToKeycode (gok_main_display (), 
 				    XStringToKeysym (output->Name));
-
+    }
     return keycode;
 }
 
-
 void
 gok_output_internal (gchar* action)
 {
