@@ -40,6 +40,7 @@
 #include "gok-modifier-keymasks.h"
 #include "gok-gconf-keys.h"
 #include "gok-word-complete.h"
+#include "gok-keyboard.h"
 
 /*
  * NOTE: we can tweak the efficiency/accuracy of the
@@ -255,6 +256,8 @@ void gok_spy_accessible_unref(Accessible* accessible)
 	gok_log_leave ();
 }
 
+extern SPIBoolean cspi_accessible_is_a (Accessible *accessible, const char *interface_name);
+
 gboolean gok_spy_accessible_is_okay(Accessible* accessible)
 {
 	gboolean returncode = FALSE;
@@ -591,7 +594,7 @@ gok_spy_node_match (AccessibleNode *node, GokSpySearchType type)
 	case GOK_SPY_SEARCH_CHILDREN:
 	case GOK_SPY_SEARCH_COMBO:
 	case GOK_SPY_SEARCH_LISTITEMS:
-	case GOK_SPY_SEARCH_TABLE_ROWS:
+	case GOK_SPY_SEARCH_TABLE_CELLS:
 	case GOK_SPY_SEARCH_ALL:
 		return TRUE;
 		break;
@@ -748,13 +751,14 @@ gok_spy_concatenate_child_names (Accessible *parent)
 
 /**
  * 
- * gok_spy_get_table_row_nodes:
+ * gok_spy_get_table_nodes:
  * Returns a list of nodes which are children of a table, such that
- * there is exactly one child per table row plus one child per actionable table header.
+ * there is exactly one child per currently visible cell 
+ * plus one child per actionable table header.
  *
  **/
 GSList *
-gok_spy_get_table_row_nodes (Accessible *search_root)
+gok_spy_get_table_nodes (Accessible *search_root)
 {
 	GSList *nodes = NULL;
 	AccessibleNodeFlags flags;
@@ -798,6 +802,8 @@ gok_spy_get_table_row_nodes (Accessible *search_root)
 	Accessible_unref (first_child);
 	Accessible_unref (last_child);
 
+	gok_log ("first row index %d; last row index %d", first_index, last_index);
+
 	row_count = AccessibleTable_getNRows (table);
 	first_row = AccessibleTable_getRowAtIndex (table, first_index);
 	if (last_index >= 0) 
@@ -829,10 +835,10 @@ gok_spy_get_table_row_nodes (Accessible *search_root)
 			{
 				nodes = gok_spy_append_node (nodes, child, flags);
 				gok_spy_accessible_unref (child);
-				break;
 			}
 			else 
 			{
+ 			        gok_log ("ignoring node at row %d, col %d", i, n);
 				gok_spy_accessible_unref (child);
 			}
 			++n;
@@ -874,7 +880,8 @@ gok_spy_get_children (Accessible *search_root)
 
 /**
  * gok_spy_get_actionable_descendants:
- * Returns a list of actionable or selectable descendants of #accessible.
+ * Returns a list of actionable or selectable descendants of #accessible,
+ * including #accessible itself.
  **/
 GSList *
 gok_spy_get_actionable_descendants (Accessible *accessible, GSList *nodes)
@@ -882,10 +889,19 @@ gok_spy_get_actionable_descendants (Accessible *accessible, GSList *nodes)
     gint child_count, i, max_children = 20;
     Accessible *child;
     AccessibleNodeFlags flags;
-    GSList *ret_nodes = nodes;
+    GSList *ret_nodes;
     gboolean is_selection = Accessible_isSelection (accessible);
     flags.value = 0;
     flags.data.is_ui = TRUE;
+
+    if (Accessible_isAction (accessible))
+    {
+	ret_nodes = gok_spy_append_node (nodes, accessible, flags);
+    }
+    else
+    {
+	ret_nodes = nodes;
+    }
     child_count = Accessible_getChildCount (accessible);
     for (i = 0; i < child_count && i < max_children; ++i) 
     {
@@ -1213,7 +1229,24 @@ gok_spy_is_menu_role (AccessibleRole role)
 
 
 static gboolean
-gok_spy_is_ui (Accessible *accessible, AccessibleRole role)
+gok_spy_is_selectable_child (Accessible *accessible, Accessible *parent)
+{
+    if (parent && Accessible_isSelection (parent))
+    {
+/* see bug #153638
+	gboolean retval;
+	AccessibleStateSet *stateset = Accessible_getStateSet (accessible);
+	retval = AccessibleStateSet_contains (stateset, SPI_STATE_SELECTABLE);
+	AccessibleStateSet_unref (stateset);
+	return retval;
+*/
+	return TRUE;
+    }
+    return FALSE;
+}
+
+static gboolean
+gok_spy_is_ui (Accessible *accessible, Accessible *parent, AccessibleRole role)
 {
 	gboolean interesting = FALSE;
 
@@ -1227,14 +1260,17 @@ gok_spy_is_ui (Accessible *accessible, AccessibleRole role)
 	case SPI_ROLE_TOGGLE_BUTTON:
 	case SPI_ROLE_SLIDER:
 	case SPI_ROLE_SCROLL_BAR:
+        case SPI_ROLE_LIST:
 		interesting = TRUE;
 		break;
 	default:
 		if (Accessible_isEditableText (accessible) ||
 		    Accessible_isHypertext (accessible) ||
 		    Accessible_isTable (accessible) ||
-		    (Accessible_isAction (accessible) && !gok_spy_is_menu_role (role)))
-			interesting = TRUE;
+		    (!gok_spy_is_menu_role (role) && 
+		     (Accessible_isAction (accessible) ||
+		      gok_spy_is_selectable_child (accessible, parent))))
+		    interesting = TRUE;
 		gok_log ("checking for interesting interfaces... %s\n", interesting ? "yes" : "no");
 		gok_log ("is icon: %s\n", role == SPI_ROLE_ICON ? "yes" : "no");
 		break;
@@ -2243,7 +2279,7 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 
 	ui_flags.value = 0;
 	parent = rootAccessible;
-	
+
 	if (gok_spy_worth_searching (parent) == FALSE) 
 	{
 		gok_log ("not worth searching.");
@@ -2293,7 +2329,7 @@ gok_spy_search_component_list (Accessible *rootAccessible, GokSpyUIFlags keyboar
 				}
 			}
 			if ((keyboard_ui_flags.data.gui || keyboard_ui_flags.data.editable_text) && 
-			    !flags.data.is_menu && !flags.data.is_toolbar_item && gok_spy_is_ui (child, role))
+			    !flags.data.is_menu && !flags.data.is_toolbar_item && gok_spy_is_ui (child, parent, role))
 			{
 				if (keyboard_ui_flags.data.gui) 
 				{
