@@ -45,7 +45,7 @@ typedef enum {
 	GOK_SPY_SEARCH_APPLICATIONS,
 	GOK_SPY_SEARCH_CHILDREN,
 	GOK_SPY_SEARCH_LISTITEMS,
-	GOK_SPY_SEARCH_TABLE_ROWS,
+	GOK_SPY_SEARCH_TABLE_CELLS,
 	GOK_SPY_SEARCH_COMBO,
 	GOK_SPY_SEARCH_ACTIONABLE,
 	GOK_SPY_SEARCH_ALL
@@ -90,11 +90,13 @@ gboolean gok_spy_is_menu_role (AccessibleRole role);
 /* gboolean gok_spy_is_desktop(Accessible* pAccessible); */
 /* gboolean gok_spy_accessible_is_desktopChild(Accessible* accessible); */
 Accessible*     gok_spy_get_active_frame (void );
+Accessible*     gok_spy_get_focussed_object (void );
 GSList*         gok_spy_get_list (Accessible* paccessible); 
 Accessible*     gok_spy_get_list_parent (Accessible* paccessible);
 Accessible*     gok_spy_get_editable (Accessible* paccessible);
 GSList*         gok_spy_get_children (Accessible* paccessible); 
 GSList*         gok_spy_get_actionable_descendants (Accessible* paccessible, GSList *nodes); 
+GSList*         gok_spy_get_table_nodes (Accessible* paccessible); 
 GokSpyUIFlags   gok_spy_update_component_list (Accessible* accessible, GokSpyUIFlags keyboard_ui_flags);
 AccessibleNode* gok_spy_get_ui_list (Accessible* paccessible); 
 AccessibleNode* gok_spy_refresh (AccessibleNode* plist); 
